/*
Copyright 2003/2004, Freie Universitaet Berlin. All rights reserved.

These sources were developed at the Freie Universitt Berlin, Computer
Systems and Telematics group.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.
 
- Neither the name of Freie Universitaet Berlin (FUB) nor the names of its
contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

This software is provided by FUB and the contributors on an "as is"
basis, without any representations or warranties of any kind, express
or implied including, but not limited to, representations or
warranties of non-infringement, merchantability or fitness for a
particular purpose. In no event shall FUB or contributors be liable
for any direct, indirect, incidental, special, exemplary, or
consequential damages (including, but not limited to, procurement of
substitute goods or services; loss of use, data, or profits; or
business interruption) however caused and on any theory of liability,
whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even
if advised of the possibility of such damage.

This implementation was developed by the CST group at the FUB.
Contributors: Marco hutta

For documentation and questions please use the web site
http://www.scatterweb.net and the mailinglist
scatterweb@lists.spline.inf.fu-berlin.de (subscription via the Website).
Berlin, 2003/2004/2005
*/

#ifndef ScatterWeb_IO
#define ScatterWeb_IO

/// Temporary switch for the eeprom address. 
#define EEPROMADDRESS (0x00) // use 8k EEPROM, future versions will have only one 64k eeprom at this address
//#define EEPROMADDRESS (0x02)   // use 64k EEPROM

// must be set together with EEPROMADDRESS
//#define EEPROMPAGEMASK (0x1F)  //  8k EEPROM, 32b page writes possible
#define EEPROMPAGEMASK (0x7F)  // 64k EEPROM, 128b page writes possible

/*
 * Erases bytes of data of the eeprom
 *  
 * @return bool     True if erase successful, otherwise False        
 *  
 */
bool IO_erase(UINT16 e_adr, UINT16 size);

/*
 * Reads bytes of data from the eeprom
 * 
 * @return UINT8*   pointer of data        
 *  
 */
UINT8* IO_read(int e_adr, char* r_adr, int size);                                                                         

/*
 * Writes bytes of data to the eeprom
 * 
 *  @return bool     True if write successful, otherwise False          
 *       
 */
bool IO_write(UINT16 e_adr, UINT8* r_adr, UINT16 size);

#endif
